package meerkat.registry.AsyncRegistryCallbacks;

import com.google.common.util.concurrent.FutureCallback;
import meerkat.protobuf.BulletinBoardAPI.BulletinBoardMessage;
import meerkat.registry.RegistryTags;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.List;

import static meerkat.util.BulletinBoardUtils.findTagWithPrefix;


/**
 * Created by  Vladimir Eliezer Tokarev on 3/12/2016.
 * AsyncRegistry hasVoted creates this callback to check if wanted user has voted
 */
public class HasVotedCallback implements FutureCallback<List<BulletinBoardMessage>>{
    protected FutureCallback<Boolean> callback;
    final Logger logger = LoggerFactory.getLogger(getClass());

    public  HasVotedCallback(FutureCallback<Boolean> callback){
        logger.debug("Initialized HasVotedCallback : ", new java.util.Date().getTime());
        this.callback = callback;
    }

    @Override
    public void onSuccess(List<BulletinBoardMessage> messages) {
        if (messages.isEmpty()){
            callback.onSuccess(false);
            return;
        }

        logger.debug("The next voter has voted: ",
                     findTagWithPrefix(messages.get(0), RegistryTags.ID_TAG),
                     new java.util.Date().getTime());
        callback.onSuccess(true);
    }

    @Override
    public void onFailure(Throwable t) {
        logger.error("Error occurred while trying to check if voter has voted: ",
                     new java.util.Date().getTime(),
                     t);
        this.callback.onFailure(t);
    }
}
