package meerkat.registry;

import com.sun.deploy.util.StringUtils;
import meerkat.protobuf.BulletinBoardAPI.FilterType;
import meerkat.protobuf.BulletinBoardAPI.MessageFilter;
import meerkat.protobuf.BulletinBoardAPI.MessageFilterList;
import org.slf4j.Logger;

import java.util.List;


/**
 * Created by Vladimir Eliezer Tokarev  on 1/15/2016.
 * adds extra functionality to Messages collections
 */
public abstract class MessageCollectionUtils {
    /**
     * Creates list of filters based on given list of strings (that are tags)
     *
     * @param logger logger object with debug method
     * @param tags the tags based on which the messages will be filtered
     * @return MessageFilterList.
     */
    public static MessageFilterList generateFiltersFromTags(List<String> tags, Logger logger) {
        if (tags == null){
            return MessageFilterList.getDefaultInstance();
        }

        MessageFilterList.Builder filters = MessageFilterList.newBuilder();

        for (String tag : tags) {
            MessageFilter filter = MessageFilter.newBuilder().setTag(tag).setType(FilterType.TAG).build();
            filters.addFilter(filter);
        }

        logger.debug("Converted next strings to filters", StringUtils.join(tags, " "));

        return filters.build();
    }
}
