package polling_station_dashboard.java;

import javafx.stage.Stage;
import polling_station_dashboard.search.SearchHandler;
import polling_station_dashboard.search.VotersFetcher.DummyVotersFetcher;
import polling_station_dashboard.search.addVoter.java.AddVoterLoader;
import polling_station_dashboard.settings.java.SettingsVisualUpdater;
import polling_station_dashboard.settings.java.settingsLoader;
import polling_station_dashboard.statusLog.java.StatusLogLoader;
import polling_station_dashboard.statusLog.java.StatusLogVisualUpdater;

import java.io.IOException;

/**
 * Created by Vladimir Eliezer Tokarev on 12/06/2016.
 * EventHandlerMapper creates EventHandlerMap with objects that handles next parts:
 * 1.   Status Log extension
 * 2.   Settings extension
 * 3.   Search Handling
 */
public class EventHandlerMapper {

    public static EventHandlerMap CreateEventHandlerMap(Stage primaryStage) throws IOException
    {
        EventHandlerMap map = new EventHandlerMap();

        // Map status log objects to settings visual updater
        settingsLoader settingsLoader = new settingsLoader(primaryStage);
        SettingsVisualUpdater settingsVisualUpdater =
                new SettingsVisualUpdater(settingsLoader.GetSettingsInstance(), primaryStage);
        map.Add("SettingsButton", settingsVisualUpdater);
        map.Add("Settings", settingsVisualUpdater);

        // map settings objects to status log visual updater
        StatusLogLoader statusLogLoader = new StatusLogLoader(primaryStage);
        StatusLogVisualUpdater statusLogVisualUpdater =
                new StatusLogVisualUpdater(statusLogLoader.GetStatusLogInstance(), primaryStage);
        map.Add("StatusLogButton", statusLogVisualUpdater);
        map.Add("statusLog", statusLogVisualUpdater);

        // map add voter to search button triggered
        SearchHandler searchHandler = new SearchHandler(primaryStage, new DummyVotersFetcher());
        map.Add("SearchButton", searchHandler);
        return map;
    }

}
